from distutils.core import setup

setup(
    name="hello_009",
    author="xxx",
    version="1.0.0",
    author_email="xxx@gmail.com",
    py_modules=['hellopy.hello'],
    url="http://www.xxx.com"
)